import { z } from "zod";
import { ServerConfig } from "../../types/config";

const envSchema = z.object({
  HOST: z.string().default("localhost"),
  PORT: z.coerce.number().default(3000),
  API_VERSION: z.coerce.number().default(1),
  ALLOWED_ORIGINS: z.string().default("http://localhost:3000"),
});

const { error, data: envVars } = envSchema.safeParse(process.env);
if (error) {
  throw new Error(`Config validation error: ${error.message}`);
}

export const server: ServerConfig = {
  host: envVars.HOST,
  port: envVars.PORT,
  apiVersion: envVars.API_VERSION,
  origins: envVars.ALLOWED_ORIGINS.split(","),
};
